[Rt-commit] rt branch, 3.8-trunk, updated. rt-3.8.8-99-gc8f0e72

Emannuel Lacour elacour at bestpractical.com
Thu Jun 24 09:03:24 EDT 2010


The branch, 3.8-trunk has been updated
       via  c8f0e722c5cb81e72e2e3abc89ddfc0c396bc0f7 (commit)
      from  d9394159614ef51c575aa0af82921385905928f4 (commit)

Summary of changes:
 lib/RT/Attribute_Overlay.pm |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

- Log -----------------------------------------------------------------
commit c8f0e722c5cb81e72e2e3abc89ddfc0c396bc0f7
Author: Emmanuel Lacour <elacour at easter-eggs.com>
Date:   Thu Jun 24 15:03:48 2010 +0200

    Fix "update" permissions for SavedSearch that allowed people to modify a group saved search without EditSavedSearches on it

diff --git a/lib/RT/Attribute_Overlay.pm b/lib/RT/Attribute_Overlay.pm
index 4d201da..c93c153 100644
--- a/lib/RT/Attribute_Overlay.pm
+++ b/lib/RT/Attribute_Overlay.pm
@@ -73,7 +73,7 @@ our $ACL_MAP = {
 };
 
 # There are a number of attributes that users should be able to modify for themselves, such as saved searches
 #  we could do this with a different set of "modify" rights, but that gets very hacky very fast. this is even faster and even
 # hackier. we're hardcoding that a different set of rights are needed for attributes on oneself
 our $PERSONAL_ACL_MAP = { 
     SavedSearch => { create => 'ModifySelf',
@@ -393,7 +393,7 @@ sub _Value {
 
 sub _Set {
     my $self = shift;
-    unless ($self->CurrentUserHasRight('modify')) {
+    unless ($self->CurrentUserHasRight('update')) {
 
         return (0,$self->loc('Permission Denied'));
     }
@@ -404,7 +404,7 @@ sub _Set {
 
 =head2 CurrentUserHasRight
 
-One of "display" "modify" "delete" or "create" and returns 1 if the user has that right for attributes of this name for this object.Returns undef otherwise.
+One of "display" "update" "delete" or "create" and returns 1 if the user has that right for attributes of this name for this object.Returns undef otherwise.
 
 =cut
 

-----------------------------------------------------------------------
@@ -73,7 +73,7 @@ our $ACL_MAP = {
 
 # There are a number of attributes that users should be able to modify for themselves, such as saved searches
-#  we could do this with a different set of "modify" rights, but that gets very hacky very fast. this is even faster and even
+#  we could do this with a different set of "update" rights, but that gets very hacky very fast. this is even faster and even
 # hackier. we're hardcoding that a different set of rights are needed for attributes on oneself
 our $PERSONAL_ACL_MAP = { 


More information about the Rt-commit mailing list